import axios from 'axios'
import { useUserStore } from '@/stores'
import { ElMessage } from 'element-plus'
// import router from '@/router'
// const baseURL = 'https://cgyy.ecjtu.edu.cn/api'
const baseURL = 'https://www.ruanjiansc.cn/api'
// const baseURL = 'http://172.16.6.53:9020'
// const baseURL = 'http://localhost:9020/api'

const instance = axios.create({
  // TODO 1. 基础地址，超时时间
  baseURL,
  timeout: 10000
})

// 请求拦截器
instance.interceptors.request.use(
  (config) => {
    // TODO 2. 携带token
    const useStore = useUserStore()
    if (useStore.token) {
      config.headers.Authorization = useStore.token
    }
    return config
  },
  (err) => Promise.reject(err)
)

// 响应拦截器
instance.interceptors.response.use(
  (res) => {
    // TODO 3. 处理业务失败
    // TODO 4. 摘取核心响应数据
    if (res.data.code === 200) {
      // 成功
      return res
    }
    // 失败返回
    if (res.data.code === 201) {
      ElNotification({
        title: 'Warning',
        message: res.data.message,
        type: 'warning'
      })
    }
    // 服务异常
    if (res.data.code === 500) {
      ElMessage.error('服务异常')
    }
    return Promise.reject(res.data)
  },
  (err) => {
    // 错误的默认情况，只要给提示
    ElMessage.error(err.response.data.message || '服务异常')
    return Promise.reject(err)
  }
)

export default instance
export { baseURL }
